#
# spec file for package e2fsprogs
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# This file and all modifications and additions to the pristine
# package are under the same license as the package itself.
#
# Please submit bugfixes or comments via http://bugs.opensuse.org/

%bcond_without lustre

%define build_mini 0
%define tar_version 1.44.5

%if %{with lustre}
%define suffix .wc1
%endif


Name:           e2fsprogs
%if 0%{?suse_version} >= 1010
# Hint for ZYPP
Supplements:    filesystem(ext2) filesystem(ext3) filesystem(ext4)
%if %{with lustre}
Supplements:	filesystem(ldiskfs)
%endif
%endif
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libblkid-devel
BuildRequires:  libuuid-devel
BuildRequires:  pkg-config
%if ! %{build_mini}
%if 0%{?suse_version} > 1220
BuildRequires:  makeinfo
%endif
# Define info macros if missing (for Fedora builds)
%if 0%{!?%install_info_prereq:1}
%define install_info_prereq info
%define install_info sbin/install-info
%define install_info_delete sbin/install-info --delete
%endif
Requires:       %install_info_prereq
%endif
# bug437293
%ifarch ppc64
Obsoletes:      e2fsprogs-64bit
%endif

%if %{build_mini}
Conflicts:      e2fsprogs
Conflicts:      e2fsprogs-devel
Conflicts:      libext2fs2
Conflicts:      libext2fs-devel
Conflicts:      libcom_err2
Conflicts:      libcom_err-devel
%else
Conflicts:      e2fsprogs-mini
Conflicts:      e2fsprogs-mini-devel
Conflicts:      libext2fs2-mini
Conflicts:      libext2fs-mini-devel
Conflicts:      libcom_err2-mini
Conflicts:      libcom_err-mini-devel
%endif
#
Version:        %{tar_version}%{?suffix}
Release:        3.1
Summary:        Utilities for managing ext2/3/4 filesystems
License:        GPL-2.0
Group:          System/Filesystems
Url:            http://e2fsprogs.sourceforge.net
Requires(post): coreutils
%if %{with lustre}
Requires:       libcom_err(ldiskfs) >= %{tar_version}
Requires:       libext2fs2(ldiskfs) >= %{tar_version}
Provides:       ldiskfsprogs = %{version}
%else
Requires:       libcom_err >= %{tar_version}
Requires:       libext2fs2 >= %{tar_version}
%endif
Source:         http://www.kernel.org/pub/linux/kernel/people/tytso/e2fsprogs/v%{tar_version}/e2fsprogs-%{tar_version}.tar.xz
Source1:	e2fsprogs-%{tar_version}.tar.sign
Source2:        README.SUSE
Source3:        baselibs.conf
Source4:	ldiskfsprogs-tests.tar.xz
Source5:	e2fsprogs.keyring

#
# e2fsprogs patches
#
# libcom_err patches
Patch3:         libcom_err-compile_et_permissions.patch
Patch4:         e2fsprogs-1.42-implicit_fortify_decl.patch
Patch5:         e2fsprogs-1.42-ext2fsh_implicit.patch

# Lustre/LDISKFS patches
Patch500:   build-update-version-for-lustre-build.patch
Patch501:   filefrag-lustre-changes-to-filefrag-fiemap-handling.patch
Patch502:   build-update-e2fsprogs-spec-for-distro-builds.patch
Patch503:   build-add-rhel6-spec-file-for-packaging.patch
Patch504:   tt-177-build-add-spec-file-for-sles11-packaging.patch
Patch505:   tests-verify-65000-subdirectories.patch
Patch506:   e2fsck-parse-config-file-before-command-line-opts.patch
Patch507:   e2fsck-allow-deleting-or-zeroing-shared-blocks.patch
Patch508:   tune2fs-warn-if-the-filesystem-journal-is-dirty.patch
Patch509:   tests-add-tests-for-uninitialized-bitmaps.patch
Patch510:   e2fsck-add-support-for-expanding-the-inode-size.patch
Patch511:   tests-add-tests-for-expanding-inode-extra-size.patch
Patch512:   e2fsck-track-errors-badness-found-for-each-inode.patch
Patch513:   tests-add-test-cases-for-inode-badness.patch
Patch514:   e2fsck-clean-up-xattr-checking-code.patch
Patch515:   libext2fs-add-a-regression-test-for-in-inode-xattrs.patch
Patch516:   tests-verify-large-xattr-inode-support.patch
Patch517:   e2fsck-add-support-for-dirdata-feature.patch
Patch518:   tests-add-basic-tests-for-dirdata-feature.patch
Patch519:   debugfs-dump-fid-and-lma-xattrs-on-inode-stat.patch
Patch520:   ext2fs-check-if-lustre-filesystem-is-mounted.patch
Patch521:   lu-1540-e2fsck-add-missing-symlink-nul-terminator.patch
Patch522:   lu-5307-build-add-support-for-rhel-7-spec-file.patch
Patch523:   lu-5845-build-add-support-for-suse_linux-12-spec-file.patch
Patch524:   lu-6722-jbd-double-minimum-journal-size-for-rhel7.patch
Patch525:   lu-9501-mke2fs-avoid-inode-number-error-with-large-fs.patch
Patch526:   lu-8300-e2fsck-print-out-fid-with-dirent-inode-number.patch
Patch527:   lu-10638-build-add-support-for-scientific.patch
Patch528:   lu-11215-libe2p-add-large_xattr-as-an-alias-of-ea_inode.patch
Patch529:   e2fsck-allow-to-check-2gb-sized-directory.patch
Patch530:   debugfs-output-large-directory-size.patch
Patch531:   lu-11609-mke2fs-allow-64bit-feature-without-extents.patch

# Do not suppress make commands
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Utilities needed to create and maintain ext2 and ext3 file systems
under Linux. Included in this package are: chattr, lsattr, mke2fs,
mklost+found, tune2fs, e2fsck, resize2fs, and badblocks.

%package devel
Summary:        Dummy development package
# bug437293
License:        LGPL-2.0
Group:          Development/Libraries/C and C++
%ifarch ppc64
Obsoletes:      e2fsprogs-devel-64bit
%endif
#
Requires:       libblkid-devel
Requires:       libext2fs-devel = %version
Requires:       libuuid-devel

%description devel
Dummy development package for backwards compatibility.

%if %{build_mini}
%package -n libext2fs2-mini
%else
%package -n libext2fs2
%endif
Summary:        Ext2fs library
License:        LGPL-2.0
Group:          System/Filesystems
%if %{with lustre}
Provides:	libext2fs2(ldiskfs) = %{tar_version}
%endif

%if %{build_mini}
%description -n libext2fs2-mini
%else
%description -n libext2fs2
%endif
The basic Ext2fs shared library.

%if %{build_mini}
%package -n libext2fs-mini-devel
%else
%package -n libext2fs-devel
%endif
Summary:        Development files for libext2fs
License:        LGPL-2.0
Group:          Development/Libraries/C and C++
Requires:       libcom_err-devel
Requires:       libext2fs2 = %version

%if %{build_mini}
%description -n libext2fs-mini-devel
%else
%description -n libext2fs-devel
%endif
Development files for libext2fs.

%if ! %{build_mini}
%package -n libext2fs-devel-static
Summary:        Development files for libext2fs
License:        LGPL-2.0
Group:          Development/Libraries/C and C++
Requires:       libext2fs-devel = %{version}
Provides:       libext2fs-devel:%{_libdir}/libe2p.a
Provides:       libext2fs-devel:%{_libdir}/libext2fs.a

%description -n libext2fs-devel-static
Development files for libext2fs. Static libraries.
%endif

%if %{build_mini}
%package -n libcom_err2-mini
%else
%package -n libcom_err2
%endif
Summary:        E2fsprogs error reporting library
# bug437293
License:        MIT
Group:          System/Filesystems
%ifarch ppc64
Obsoletes:      libcom_err-64bit
Obsoletes:      libcom_err2-64bit
%endif
#
Provides:       libcom_err = %{version}
%if %{with lustre}
Provides:	libcom_err(ldiskfs) = %{tar_version}
%endif
Obsoletes:      libcom_err <= 1.40

%if %{build_mini}
%description -n libcom_err2-mini
%else
%description -n libcom_err2
%endif
com_err is an error message display library.

%if %{build_mini}
%package -n libcom_err-mini-devel
%else
%package -n libcom_err-devel
%endif
Summary:        Development files for libcom_err
# bug437293
License:        MIT
Group:          Development/Libraries/C and C++
%ifarch ppc64
Obsoletes:      libcom_err-devel-64bit
%endif
#
Requires:       glibc-devel
Requires:       libcom_err2 = %version

%if %{build_mini}
%description -n libcom_err-mini-devel
%else
%description -n libcom_err-devel
%endif
Development files for the com_err error message display library.

%if ! %{build_mini}
%package -n libcom_err-devel-static
Summary:        Development files for libcom_err, static libraries
License:        MIT
Group:          Development/Libraries/C and C++
Requires:       libcom_err-devel = %{version}
Provides:       libcom_err-devel:%{_libdir}/libcom_err.a
Provides:       libcom_err-devel:%{_libdir}/libss.a
# bug437293
%ifarch ppc64
Obsoletes:      libcom_err-devel-64bit
%endif
#

%description -n libcom_err-devel-static
Development files for the com_err error message display library. Static libraries.
%endif

%prep
%setup -q -n e2fsprogs-%{tar_version} -a 4
# e2fsprogs patches
# libcom_err patches
%patch3 -p1
%patch4
%patch5
cp %{SOURCE2} .

%if %{with lustre}
%patch500 -p1
%patch501 -p1
%patch502 -p1
%patch503 -p1
%patch504 -p1
%patch505 -p1
%patch506 -p1
%patch507 -p1
%patch508 -p1
%patch509 -p1
%patch510 -p1
%patch511 -p1
%patch512 -p1
%patch513 -p1
%patch514 -p1
%patch515 -p1
%patch516 -p1
%patch517 -p1
%patch518 -p1
%patch519 -p1
%patch520 -p1
%patch521 -p1
%patch522 -p1
%patch523 -p1
%patch524 -p1
%patch525 -p1
%patch526 -p1
%patch527 -p1
%patch528 -p1
%patch529 -p1
%patch530 -p1
%patch531 -p1
%endif

%build
autoreconf --force --install
%configure \
  --disable-evms \
  --with-root-prefix=''   \
  --enable-elf-shlibs \
  --disable-libblkid \
  --disable-libuuid \
  --disable-uuidd \
  --disable-fsck \
  --enable-static \
  CFLAGS="$RPM_OPT_FLAGS"
%if %{build_mini}
rm -rf doc
%endif
make %{?_smp_mflags} V=1
#Guarantee that tranlations match the source messages
make -C po update-po

%install
make install install-libs DESTDIR=$RPM_BUILD_ROOT ELF_INSTALL_DIR=/%{_libdir}
rm -f $RPM_BUILD_ROOT/usr/sbin/mkfs.ext4dev
rm -f $RPM_BUILD_ROOT/usr/sbin/fsck.ext4dev

%{find_lang} e2fsprogs

rm $RPM_BUILD_ROOT%{_libdir}/e2initrd_helper

#UsrMerge
mkdir %{buildroot}/sbin
ln -s %{_sbindir}/badblocks %{buildroot}/sbin/badblocks
ln -s %{_sbindir}/debugfs   %{buildroot}/sbin/debugfs
ln -s %{_sbindir}/dumpe2fs  %{buildroot}/sbin/dumpe2fs
ln -s %{_sbindir}/e2undo    %{buildroot}/sbin/e2undo
ln -s %{_sbindir}/e2fsck    %{buildroot}/sbin/e2fsck
ln -s %{_sbindir}/e2label   %{buildroot}/sbin/e2label
ln -s %{_sbindir}/fsck.ext2 %{buildroot}/sbin/fsck.ext2
ln -s %{_sbindir}/fsck.ext3 %{buildroot}/sbin/fsck.ext3
ln -s %{_sbindir}/fsck.ext4 %{buildroot}/sbin/fsck.ext4
ln -s %{_sbindir}/mke2fs    %{buildroot}/sbin/mke2fs
ln -s %{_sbindir}/mkfs.ext2 %{buildroot}/sbin/mkfs.ext2
ln -s %{_sbindir}/mkfs.ext3 %{buildroot}/sbin/mkfs.ext3
ln -s %{_sbindir}/mkfs.ext4 %{buildroot}/sbin/mkfs.ext4
ln -s %{_sbindir}/resize2fs %{buildroot}/sbin/resize2fs
ln -s %{_sbindir}/tune2fs   %{buildroot}/sbin/tune2fs
ln -s %{_sbindir}/e2image   %{buildroot}/sbin/e2image
ln -s %{_sbindir}/logsave   %{buildroot}/sbin/logsave
mkdir %{buildroot}/%{_lib}
pushd %{buildroot}/%{_libdir}
LIBNAMES=$(ls *.so.*)
popd
for libName in $LIBNAMES;
  do ln -s %{_libdir}/$libName %{buildroot}/%{_lib};
done
#EndUsrMerge
%post
/sbin/ldconfig
%if ! %{build_mini}
%install_info --info-dir=%{_infodir} %{_infodir}/libext2fs.info.gz || :
%{?regenerate_initrd_post}
%endif

%postun
/sbin/ldconfig
%if ! %{build_mini}
%install_info_delete --info-dir=%{_infodir} %{_infodir}/libext2fs.info.gz || :
%{?regenerate_initrd_post}
%endif

%if ! %{build_mini}
%posttrans
%{?regenerate_initrd_posttrans}
%endif

%if %{build_mini}
%post -n libext2fs2-mini -p /sbin/ldconfig
%else
%post -n libext2fs2 -p /sbin/ldconfig
%endif

%if %{build_mini}
%postun -n libext2fs2-mini -p /sbin/ldconfig
%else
%postun -n libext2fs2 -p /sbin/ldconfig
%endif

%if %{build_mini}
%post -n libcom_err2-mini -p /sbin/ldconfig
%else
%post -n libcom_err2 -p /sbin/ldconfig
%endif

%if %{build_mini}
%postun -n libcom_err2-mini -p /sbin/ldconfig
%else
%postun -n libcom_err2 -p /sbin/ldconfig
%endif

%files -f e2fsprogs.lang
%defattr(-, root, root)
%doc RELEASE-NOTES README
%config /etc/mke2fs.conf
#UsrMerge 
/sbin/badblocks
/sbin/debugfs
/sbin/dumpe2fs
/sbin/e2undo
/sbin/e2fsck
/sbin/e2label
/sbin/fsck.ext2
/sbin/fsck.ext3
/sbin/fsck.ext4
/sbin/mke2fs
/sbin/mkfs.ext2
/sbin/mkfs.ext3
/sbin/mkfs.ext4
/sbin/resize2fs
/sbin/tune2fs
/sbin/e2image
/sbin/logsave
#EndUsrMerge
%{_sbindir}/badblocks
%{_sbindir}/debugfs
%{_sbindir}/dumpe2fs
%{_sbindir}/e2undo
%{_sbindir}/e2fsck
%{_sbindir}/e2label
%{_sbindir}/fsck.ext2
%{_sbindir}/fsck.ext3
%{_sbindir}/fsck.ext4
%{_sbindir}/mke2fs
%{_sbindir}/mkfs.ext2
%{_sbindir}/mkfs.ext3
%{_sbindir}/mkfs.ext4
%{_sbindir}/resize2fs
%{_sbindir}/tune2fs
%{_sbindir}/e2image
%{_sbindir}/logsave
%{_bindir}/chattr
%{_bindir}/lsattr
%{_sbindir}/mklost+found
%{_sbindir}/filefrag
%{_sbindir}/e2freefrag
%{_sbindir}/e4defrag
%{_sbindir}/e2mmpstatus
%{_sbindir}/e4crypt
%if ! %{build_mini}
%{_infodir}/libext2fs.info.gz
%endif
%{_mandir}/man1/chattr.1.gz
%{_mandir}/man1/lsattr.1.gz
%{_mandir}/man5/ext?.5.gz
%{_mandir}/man5/e2fsck.conf.5.gz
%{_mandir}/man5/mke2fs.conf.5.gz
%{_mandir}/man8/*.8.gz

%files devel
%defattr(-,root,root)
%doc README.SUSE

%if %{build_mini}
%files -n libext2fs2-mini
%else
%files -n libext2fs2
%endif
%defattr(-, root, root)
#UsrMerge
/%{_lib}/libext2fs.so.*
/%{_lib}/libe2p.so.*
#EndUsrMerge
%{_libdir}/libext2fs.so.*
%{_libdir}/libe2p.so.*

%if %{build_mini}
%files -n libext2fs-mini-devel
%else
%files -n libext2fs-devel
%endif
%defattr(-, root, root)
%{_libdir}/libext2fs.so
%{_libdir}/libe2p.so
/usr/include/ext2fs
/usr/include/e2p
%_libdir/pkgconfig/e2p.pc
%_libdir/pkgconfig/ext2fs.pc

%if %{build_mini}
%files -n libcom_err2-mini
%else
%files -n libcom_err2
%endif
%defattr(-, root, root)
#UsrMerge
/%{_lib}/libcom_err.so.*
/%{_lib}/libss.so.*
#EndUsrMerge
%{_libdir}/libcom_err.so.*
%{_libdir}/libss.so.*

%if %{build_mini}
%files -n libcom_err-mini-devel
%else
%files -n libcom_err-devel
%endif
%defattr(-, root, root)
%_bindir/compile_et
%_bindir/mk_cmds
%{_libdir}/libcom_err.so
%{_libdir}/libss.so
%_libdir/pkgconfig/com_err.pc
%_libdir/pkgconfig/ss.pc
%_includedir/com_err.h
%_includedir/et
%_includedir/ss
%_datadir/et
%_datadir/ss
%{_mandir}/man1/compile_et.1.gz
%{_mandir}/man1/mk_cmds.1.gz
%{_mandir}/man3/com_err.3.gz

%if ! %{build_mini}
%files -n libcom_err-devel-static
%defattr(-, root, root)
%{_libdir}/libcom_err.a
%{_libdir}/libss.a

%files -n libext2fs-devel-static
%defattr(-, root, root)
%{_libdir}/libext2fs.a
%{_libdir}/libe2p.a
%endif

%changelog
* Tue Apr 16 2019 jeffm@suse.com
- Refresh against lustre-master:
  * Updated baseline e2fsprogs to 1.44.5.
  * Added patches:
  - build-add-rhel6-spec-file-for-packaging.patch
  - build-update-e2fsprogs-spec-for-distro-builds.patch
  - build-update-version-for-lustre-build.patch
  - debugfs-output-large-directory-size.patch
  - e2fsck-allow-to-check-2gb-sized-directory.patch
  - e2fsck-clean-up-xattr-checking-code.patch
  - ext2fs-check-if-lustre-filesystem-is-mounted.patch
  - filefrag-lustre-changes-to-filefrag-fiemap-handling.patch
  - libext2fs-add-a-regression-test-for-in-inode-xattrs.patch
  - lu-10638-build-add-support-for-scientific.patch
  - lu-11215-libe2p-add-large_xattr-as-an-alias-of-ea_inode.patch
  - lu-11609-mke2fs-allow-64bit-feature-without-extents.patch
  - lu-1540-e2fsck-add-missing-symlink-nul-terminator.patch
  - lu-5307-build-add-support-for-rhel-7-spec-file.patch
  - lu-5845-build-add-support-for-suse_linux-12-spec-file.patch
  - lu-6722-jbd-double-minimum-journal-size-for-rhel7.patch
  - lu-8300-e2fsck-print-out-fid-with-dirent-inode-number.patch
  - lu-9501-mke2fs-avoid-inode-number-error-with-large-fs.patch
  - tests-add-tests-for-expanding-inode-extra-size.patch
  - tt-177-build-add-spec-file-for-sles11-packaging.patch
  * Removed patches:
  - 0001-debian-remove-trailing-spaces-from-control.in-file.patch
  - 0002-Revert-aclocal.m4-update-to-newer-versions-of-autoco.patch
  - 0003-build-update-version-for-Lustre-build.patch
  - 0004-tests-make-generated-test-scripts-read-only.patch
  - 0005-LU-5307-build-fix-unused-uninitialized-variable-warn.patch
  - 0006-e2fsck-improve-in-inode-xattr-checks.patch
  - 0007-blkid-fix-ZFS-device-detection.patch
  - 0008-filefrag-Lustre-changes-to-filefrag-FIEMAP-handling.patch
  - 0009-build-update-e2fsprogs.spec-for-distro-builds.patch
  - 0010-build-add-RHEL6-.spec-file-for-packaging.patch
  - 0011-TT-177-build-add-.spec-file-for-SLES11-packaging.patch
  - 0012-e2fsck-ignore-xattr-feature-in-backup-superblocks.patch
  - 0014-e2fsck-mark-device-inodes-with-EXT4_EXTENTS_FL-bad.patch
  - 0015-tests-extent-pointing-to-non-existent-block.patch
  - 0016-tests-invalid-value-of-in-inode-EA-offset.patch
  - 0021-e2fsck-handle-preallocation-for-large-PAGE_SIZE.patch
  - 0022-tests-PAGE_SIZE-larger-than-blocksize-with-hole.patch
  - 0024-tests-add-tests-for-expanding-inode-extra-size.patch
  - 0027-tests-create-random-filesystem-corrupt-e2fsck.patch
  - 0028-tests-add-checks-for-journal-checksum-feature.patch
  - 0029-e2fsck-clean-up-xattr-checking-code-add-test.patch
  - 0030-e2fsck-add-support-for-xattrs-in-external-inodes.patch
  - 0034-LU-1774-tests-e2fsck-D-does-not-change-dirdata.patch
  - 0036-ext2fs-check-if-Lustre-filesystem-is-mounted.patch
  - 0037-ext2fs-add-readahead-method-to-improve-scanning.patch
  - 0038-e2scan-a-tool-for-fast-namespace-inode-scanning.patch
  - 0039-tests-add-basic-test-case-for-e2scan.patch
  - 0040-LU-1502-build-enable-quota-when-building.patch
  - 0041-LU-1540-e2fsck-add-missing-symlink-NUL-terminator.patch
  - 0042-LU-5307-build-add-support-for-RHEL-7-.spec-file.patch
  - 0043-LU-5501-revert-blkid-ext2fs-avoid-name-clash-with-__.patch
  - 0044-LU-5845-build-add-support-for-SUSE_LINUX-12-.spec-fi.patch
  - 0045-LU-6722-jbd-double-minimum-journal-size-for-RHEL7.patch
  - 0046-LU-7267-e2fsck-remove-duplicated-ea-value-size-check.patch
  - 0047-libext2fs-fix-parents-when-modifying-extents.patch
  - 0048-LU-7368-e2fsck-skip-quota-update-when-interrupted.patch
  - 0049-LU-7381-libext2fs-fix-block-mapped-file-punch.patch
  - 0050-LU-7381-e2fsck-fix-e2fsck-fD-directory-truncation.patch
  - 0051-LU-7381-e2fsprogs-update-build-version-to-1.42.13.wc.patch
  - 0052-LDEV-325-e2fsprogs-even-up-build-version-of-distros.patch
  - 0053-LU-7867-debugfs-fix-check-for-out-of-bound-xattr-val.patch
  - 0054-LU-7867-e2fsprogs-update-build-version-to-1.42.13.wc.patch
  - 0055-LU-4017-e2fsprogs-always-read-full-inode-structure.patch
  - 0056-LU-4017-e2fsprogs-clean-up-codes-for-adding-new-quot.patch
  - 0057-LU-4017-e2fsprogs-add-project-feature.patch
  - 0058-LU-4017-e2fsprogs-add-project-quota-support.patch
  - 0059-LU-4017-e2fsprogs-add-inherit-flags-for-project-quot.patch
  - 0060-LU-4017-e2fsprogs-add-ch-ls-attr-support-for-project.patch
  - 0061-LU-4017-debugfs-add-support-for-the-project-id-field.patch
  - 0062-LU-8390-build-use-correct-.spec-file-for-SLES-12.patch
  - 0063-LU-8998-debugfs-handle-combined-LMA-EA-and-PFID-EA.patch
  - 0064-LU-8976-libext2fs-fix-maximum-bg-overhead-calculatio.patch
  - 0065-LU-4017-tune2fs-fix-BUGs-of-tuning-project-quota.patch
  - 0066-LU-9160-libext2-readahead-for-meta_bg.patch
  - 0067-LU-1365-resize2fs-clear-uninit-if-allocating-from-ne.patch
  - 0068-LU-9501-mke2fs-avoid-inode-number-error-with-large-F.patch
  - 0069-LU-10542-fix-f_dirdata-test-failure.patch
  - 0070-LU-10205-libext2fs-fix-buffer-overrun-in-ext2fs_expa.patch
  - 0071-LU-9713-build-Require-uptodate-libcom_err-libss.patch
  * Renamed patches:
  - 0013-tests-verify-65000-subdirectories.patch to
    tests-verify-65000-subdirectories.patch
  - 0017-e2fsck-parse-config-file-before-command-line-opts.patch to
    e2fsck-parse-config-file-before-command-line-opts.patch
  - 0018-e2fsck-allow-deleting-or-zeroing-shared-blocks.patch to
    e2fsck-allow-deleting-or-zeroing-shared-blocks.patch
  - 0019-tune2fs-warn-if-the-filesystem-journal-is-dirty.patch to
    tune2fs-warn-if-the-filesystem-journal-is-dirty.patch
  - 0020-tests-add-tests-for-uninitialized-bitmaps.patch to
    tests-add-tests-for-uninitialized-bitmaps.patch
  - 0023-e2fsck-add-support-for-expanding-the-inode-size.patch to
    e2fsck-add-support-for-expanding-the-inode-size.patch
  - 0025-e2fsck-track-errors-badness-found-for-each-inode.patch to
    e2fsck-track-errors-badness-found-for-each-inode.patch
  - 0026-tests-add-test-cases-for-inode-badness.patch to
    tests-add-test-cases-for-inode-badness.patch
  - 0031-tests-verify-large-xattr-inode-support.patch to
    tests-verify-large-xattr-inode-support.patch
  - 0032-e2fsck-add-support-for-dirdata-feature.patch to
    e2fsck-add-support-for-dirdata-feature.patch
  - 0033-tests-add-basic-tests-for-dirdata-feature.patch to
    tests-add-basic-tests-for-dirdata-feature.patch
  - 0035-debugfs-dump-fid-and-lma-xattrs-on-inode-stat.patch to
    debugfs-dump-fid-and-lma-xattrs-on-inode-stat.patch
* Fri Mar 23 2018 jeffm@suse.com
- Refreshed against lustre-master
  - LU-10542: fix f_dirdata test failure
  - LU-9713 build: Require uptodate libcom_err, libss
- Renamed patches to match git-format-patch
  * Added 0069-LU-10542-fix-f_dirdata-test-failure.patch
  * Added 0071-LU-9713-build-Require-uptodate-libcom_err-libss.patch
* Tue Nov  7 2017 jeffm@suse.com
- libext2fs: fix buffer overrun in ext2fs_expand_extra_isize
  * Added patch lu-10205-libext2fs-fix-buffer-overrun-in-ext2fs_expand_extra_isize.patch
* Tue Nov  7 2017 jeffm@suse.com
- Initial packaging.
