# needssslcertforbuild

# lustre.spec

# Declare rpmbuild --with/--without parameters
%bcond_without servers
%bcond_without ldiskfs
%bcond_with zfs
%bcond_without lustre_tests
%bcond_without lustre_utils
%bcond_without lustre_iokit
%bcond_without lustre_modules
%bcond_with lnet_dlc
%bcond_without manpages
%bcond_without shared
%bcond_without static
%bcond_with    systemd

%if 0%{?lustre_client_only}
%undefine with_servers
%endif

%if %{without servers}
    # --without servers overrides --with {ldiskfs|zfs}
    # so undefine the internal variables set by bcond_*
    %undefine with_ldiskfs
    %undefine with_zfs
%endif

%{!?version: %global version 2.10.5}
%{!?kver:    %global kver    %(uname -r)}
%{!?kdir:    %global kdir    /lib/modules/%{kver}/source}
%{!?kobjdir: %global kobjdir %(if [ "%{kdir}" = "/lib/modules/%{kver}/source" ]; then echo "/lib/modules/%{kver}/build"; else echo "%{kdir}"; fi)}

# as an alternative to this implementation we could simply "make -C $kdir kernelversion"
%{!?kversion: %global kversion %(files="include/generated/utsrelease.h include/linux/utsrelease.h include/linux/version.h"; for f in $files; do if test -r %{kobjdir}/$f && grep UTS_RELEASE %{kobjdir}/$f >/dev/null; then sed -ne '/^#define UTS_RELEASE/s/.*"\\(.*\\)"$/\\1/p' %{kobjdir}/$f; break; fi; done)}

# We set this because kernel_module_package has its own method of identifying
# which kernel to build against, and it is unlikely that its decision will
# match with Lustre's method of selecting which kernel to build against.
# By setting this variable, we override kernel_module_package's kernel
# selection with our selection.
%{!?kernel_version: %global kernel_version %kversion}

# in order to get kernel symset and/or kernel module dependencies into
# the RPM, in order to support weak-modules, the internal dependency gen-
# erator needs to be disabled
# this is done with (reduce the double % down to a single %):
#
# %%global _use_internal_dependency_generator 0
#
# on SLES10, /usr/lib/rpm/macros already sets this, so no harm in also
# defining it here (until Suse changes their mind)
#
# on RHEL5, however, we do need to explicitly disable the internal dep-
# endency generator and allow the external one be used
# but since RedHat's kABI is only a subset of the total kernel ABI, it
# doesn't include all of the symbols we (or OFED for that matter) need
# until RedHat includes all of the symbols we need in their symsets we
# cannot support weak-modules
# we did e-mail the maintainer of all of this stuff @redhat but got no
# response from them
#%%global _use_internal_dependency_generator 0

# Set the package name prefix
%if %{undefined lustre_name}
    %if %{with servers}
        %global lustre_name lustre
    %else
        %global lustre_name lustre-client
    %endif
%endif

%if %{undefined kmoddir}
    %if %{defined kernel_module_package_moddir}
        %global kmoddir %{kernel_module_package_moddir}
    %else
        %if %{defined suse_kernel_module_package}
            %global kmoddir updates
        %else
            %global kmoddir extra
        %endif
    %endif
%endif

%global modules_fs_path /lib/modules/%{kversion}/%{kmoddir}

%if %{_vendor}=="redhat" || %{_vendor}=="fedora"
	%global requires_kmod_name kmod-%{lustre_name}
	%global requires_kmod_tests_name kmod-%{lustre_name}-tests
	%global requires_kmod_version %{version}
%else	#for Suse
	%global requires_kmod_name %{lustre_name}-kmp
	%global requires_kmod_tests_name %{lustre_name}-tests-kmp
	%define krequires %(echo %{kversion} | sed -e 's/\.x86_64$//' -e 's/\.i[3456]86$//' -e 's/-smp$//' -e 's/-bigsmp$//' -e 's/[-.]ppc64$//' -e 's/\.aarch64$//' -e 's/-default$//')
	%if 0%{?suse_version} >= 1200
		%global requires_kmod_version %{version}_k%(echo %{krequires} | sed -r 'y/-/_/; s/^(2\.6\.[0-9]+)_/\\1.0_/;')
	%else
		%global requires_kmod_version %{version}_%(echo %{krequires} | sed -r 'y/-/_/; s/^(2\.6\.[0-9]+)_/\\1.0_/;')
	%endif
%endif

# RHEL >= 7 comes with systemd
%if 0%{?rhel} >= 7
%define with_systemd 1
%endif

# Fedora >= 15 comes with systemd, but only >= 18 has
# the proper macros
%if 0%{?fedora} >= 18
%define with_systemd 1
%endif

# opensuse >= 12.1 comes with systemd, but only >= 13.1
# has the proper macros
%if 0%{?suse_version} >= 1310
%define with_systemd 1
%endif

Summary: Lustre File System
Name: %{lustre_name}
Version: %{version}
Release: 11.1
License: GPL-2.0
Group: System Environment/Kernel
Source: lustre-%{version}.tar.gz
Source1: kmp-lustre.preamble
Source2: kmp-lustre.files
Source3: kmp-lustre-osd-ldiskfs.preamble
Source4: kmp-lustre-osd-ldiskfs.files
Source5: kmp-lustre-osd-zfs.preamble
Source6: kmp-lustre-osd-zfs.files
Source7: kmp-lustre-tests.files
Source8: Module.supported
Source9: autogen.sh
Source10: lustre-version.m4
Patch1:	0001-ldiskfs-revert-SLES-specific-unsupported-features-pa.patch
Patch2:	0002-ldiskfs-use-shim-for-clean_bdev_aliases.patch
Patch3:	0003-autoconf-fix-documentation-for-BI_RW-and-SUBMIT_BIO_.patch
Patch4:	0004-ldiskfs-ignore-local-quilt-environment.patch
Patch5:	0005-ldiskfs-test-for-SLES-12-SP2-SP3-via-presence-of-cle.patch
Patch6:	0006-ldiskfs-add-support-for-SLES12-SP2-GA-kernel.patch
Patch7:	0007-ldiskfs-SLE12-SP3-GA-support.patch
Patch8: 0008-Forward-port-to-SLE15.patch
Patch09: 0009-ldiskfs-revert-SLES15-specific-unsupported-features-pa.patch
Patch10: 0010-ldiskfs-add-patches-for-SLE15-updates.patch
Patch11: 0011-LU-10565-osd-bi_error-pagevec_init-PAGE_CACHE_SHIFT-.patch
Patch12: 0012-LU-10565-osd-unify-interface-for-vfs.patch
Patch13: 0013-LU-10565-osd-move-ext4_tranfer_project-to-osd.patch
Patch14: 0014-LU-10560-osd-bi_bdev-is-replaced-by-bi_disk.patch
Patch15: 0015-LU-10560-llite-remove-assigning-f_version-in-ll_read.patch
Patch16: 0016-LU-10560-osd-bio_integrity_enabled-was-removed.patch
Patch17: 0017-LDISKFS_XATTR_MAX_LARGE_EA_SIZE
Patch18: 0018-LU-10560-libcfs-handle-rename-to-wait_queue_entry_t.patch
Patch20: 0020-LU-9934-build-address-issues-raised-by-gcc7.patch
Patch21: 0021-LU-9829-lnet-Properly-dereference-string-pointer.patch
Patch23: 0023-LU-9832-tests-Use-sys-sysmacros.h-for-major-minor-ma.patch
Patch24: 0024-LU-11044-osd-ldiskfs-ext4_dir_operations-uses-iterat.patch
Patch25: 0025-LU-11156-scrub-skip-project-quota-inode.patch
Patch26: 0026-Port-to-SLE12-SP4.patch
Patch27: 0027-Port-to-SLE15-SP1.patch
Patch28: 0028-ib_post_recv_const.patch
Patch29: 0029-Remove-libcfs-call-trace_arm64.patch
Patch30: 0030-LU-12137-ldiskfs-properly-handle-VFS-parallel-lockin.patch
Patch31: 0031-ldiskfs-local-iterate_dir

URL: https://wiki.hpdd.intel.com/
BuildRoot: %{_tmppath}/lustre-%{version}-root
Requires: %{requires_kmod_name} = %{requires_kmod_version}
BuildRequires: libtool
BuildRequires: kernel-source
BuildRequires: kernel-syms
BuildRequires: module-init-tools
BuildRequires: quilt
%if %{with servers}
Requires: lustre-osd
Requires: lustre-osd-mount
Obsoletes: lustre-client <= %{version}
Provides: lustre-client = %{version}-%{release}
%endif
# GSS requires this: BuildRequires: pkgconfig, libgssapi-devel >= 0.10
%if %{_vendor}=="redhat" || %{_vendor}=="fedora"
#suse don't support selinux
BuildRequires: libselinux-devel
Requires: libselinux
%endif
%if %{with lustre_modules}
BuildRequires: %kernel_module_package_buildreqs
%if 0%{?opensuse_bs}
BuildRequires: pesign-obs-integration
%endif
%if %{_vendor}=="redhat"
BuildRequires: redhat-rpm-config
%endif
%endif

BuildRequires: distribution-release

%if %{with systemd}
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
BuildRequires: systemd
%endif

%description
Userspace tools and files for the Lustre file system.

%if %{with lustre_modules}
%kernel_module_package -n %{name} -p %SOURCE1 -f %SOURCE2 default

%if %{with ldiskfs}
%kernel_module_package -n %{name}-osd-ldiskfs -p %SOURCE3 -f %SOURCE4 default
%if %{with lustre_utils}
%package osd-ldiskfs-mount
Summary: osd-ldiskfs-mount contains mount's ldiskfs specific dso.
Provides: lustre-osd-mount = %{version}-%{fullrelease}
Group: System Environment/Kernel

%description osd-ldiskfs-mount
LDISKFS hooks for mount/mkfs into a dynamic library.

%endif	# with lustre_utils
%endif	# with ldiskfs

%if %{with zfs}
%kernel_module_package -n %{name}-osd-zfs -p %SOURCE5 -f %SOURCE6 default
%if %{with lustre_utils}
%package osd-zfs-mount
Summary: osd-zfs-mount contains mount's zfs specific dso.
Provides: lustre-osd-mount = %{version}-%{fullrelease}
Group: System Environment/Kernel

%description osd-zfs-mount
ZFS hooks for mount/mkfs into a dynamic library.

%endif	# with lustre_utils
%endif	# with zfs

%endif # with lustre_modules

%if %{with servers}
%package resource-agents
Summary: HA Resuable Cluster Resource Scripts for Lustre
Group: System Environment/Base
Requires: lustre
Requires: resource-agents

%description resource-agents
A set of scripts to operate Lustre resources in a High Availablity
environment for both Pacemaker and rgmanager.
%endif

%package tests
Summary: Lustre testing framework
Group: System Environment/Kernel
Provides: %{name}-tests = %{version}
Requires: %{name} = %{version}, lustre-iokit
Requires: %{requires_kmod_name} = %{requires_kmod_version}
Requires: %{requires_kmod_tests_name} = %{requires_kmod_version}
Requires: attr, rsync, perl, lsof, /usr/bin/getconf

%description tests
This package contains a set of test binaries and scripts that are intended
to be used by the Lustre testing framework.

%if %{with lustre_modules}
%kernel_module_package -n %{name}-tests -f %SOURCE7 default
%endif

%if %{with lustre_iokit}
%package -n lustre-iokit
Summary: The Lustre IO-Kit is a collection of benchmark tools for a cluster with the Lustre file system.
Group: Applications/System
Requires: python > 2.2, sg3_utils

%description -n lustre-iokit
This package includes five tools:
sgpdd-survey:
A test of the 'bare metal' performance, bypassing as much of the kernel as we can. Uses the sgp_dd utility.

obdfilter-survey
This survey can be run in 3 modes to test disk I/O including the filesystem,
network I/O, and disk I/O via the network.  The script does sequential I/O
with varying numbers of threads and objects (files) by using lctl::test_brw
to drive the echo_client connected to local or remote obdfilter instances,
or remote obdecho instances.

ost-survey
This survey tests the client-to-disk performance of individual OSTs, and
ranks then for comparison.

stats-collect
This script will collect IO stats on a defined set of nodes.

ior-survey:
A script to run the IOR benchmark. The latest version can be downloaded from
http://www.llnl.gov/asci/purple/benchmarks/limited/ior/

mds-survey:
This survey tests the local metadata performance using the echo_client to drive
the MDD layer to perform operations. It is run with multiple threads (to
simulate MDT service threads) locally on the MDS node, and does not need Lustre
clients in order to run
%endif

%package devel
Summary:  Development libraries and includes for the Lustre file system
Group: Development/Libraries/C and C++

%description devel
Development libraries and includes for the Lustre file system.

%if 0%{?suse_version}
#%%debug_package
%endif

%prep
%setup -qn lustre-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch20 -p1
%patch21 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
%patch26 -p1
%if %sle_version >= 150100
%patch27 -p1
%patch28 -p1
%endif
# Only work in <= sle12p4 and <=sle15sp1 on aarch64
%ifarch aarch64
%if %{sle_version} <= 120400 || %{sle_version} == 150000 || %{sle_version} == 150100
%patch29 -p1
%endif
%endif # ifarch aarch64
%if %{sle_version} > 120300
%patch30 -p1
%patch31 -p1
%endif

cp %{SOURCE8} .
cp %{SOURCE9} .
cp %{SOURCE10} config/

ln lustre/ChangeLog ChangeLog-lustre
ln lnet/ChangeLog ChangeLog-lnet

sh autogen.sh

%build
# Set an explicit path to our Linux tree, if we can.
cd $RPM_BUILD_DIR/lustre-%{version}
# override %optflags so that the vendor's overzealous flags don't create
# build failures
%define optflags -g -O2 -Werror

CONFIGURE_ARGS="%{?configure_args}"
if [ -n "$CONFIGURE_ARGS" ]; then
	# make sure %%kdir and %%kobjdir are not in the configure arguments
	CONFIGURE_ARGS=$(echo $CONFIGURE_ARGS | sed -e 's/"\?--with-linux=[^ ][^ ]* \?//')
	CONFIGURE_ARGS=$(echo $CONFIGURE_ARGS | sed -e 's/"\?--with-linux-obj=[^ ][^ ]* \?//')
	# remove --with-kmp-moddir from configure arguments,
	# it will be set --with-kmp-moddir=%%kmoddir
	CONFIGURE_ARGS=$(echo $CONFIGURE_ARGS | sed -e 's/"\?--with-kmp-moddir=[^ ][^ ]* \?//')
fi

# we need to eval "configure" because $CONFIGURE_ARGS could have a quoted
# string in it which we don't want word splitted by the shell
# also remove (build|host|target) options because they will be specified
# inside $CONFIGURE_ARGS
# kmod tools/scripts require %{name} directory with kernel modules
%define eval_configure %(echo '%configure' | sed -e 's#\./configure#eval ./configure#' -e 's/--\\(build\\|host\\|target\\)=[^ ][^ ]* //g')

%eval_configure $CONFIGURE_ARGS \
	%{?with_lustre_tests:--enable-tests}%{!?with_lustre_tests:--disable-tests} \
	%{?with_lustre_utils:--enable-utils}%{!?with_lustre_utils:--disable-utils} \
	%{?with_lustre_modules:--enable-modules}%{!?with_lustre_modules:--disable-modules} \
	%{!?with_shared:--disable-shared} \
	%{!?with_static:--disable-static} \
	%{!?with_lustre_iokit:--disable-iokit} \
	%{!?with_ldiskfs:--disable-ldiskfs} \
	%{!?with_servers:--disable-server} \
	%{!?with_zfs:--without-zfs} \
	%{!?with_lnet_dlc:--disable-dlc} \
	%{!?with_manpages:--disable-manpages} \
	%{!?with_systemd:--with-systemdsystemunitdir=no} \
	%{?with_systemd:--with-systemdsystemunitdir=%{_unitdir}} \
	--with-linux=%{kdir} \
	--with-linux-obj=%{kobjdir} \
	--with-kmp-moddir=%{kmoddir}/%{name}

make %{?_smp_mflags} -s %{?make_args}

%install
export BRP_PESIGN_FILES='*.ko'
make install DESTDIR=$RPM_BUILD_ROOT

# RHEL's kernel_module_path macro expects that all the modules
# in a kmod package will be in modules_fs_path/<sub packagename>
# but Lustre installs all of the modules in a single pass into
# a shared location.  Since this is a restriction imposed by
# RHEL, we handle this here in the spec file rather than in
# Lustre's build system.  This is not expected to bother SLES's
# kernel_module_path macro.
basemodpath=$RPM_BUILD_ROOT%{modules_fs_path}/%{lustre_name}
%if %{with ldiskfs}
mkdir -p $basemodpath-osd-ldiskfs/fs
mv $basemodpath/fs/osd_ldiskfs.ko $basemodpath-osd-ldiskfs/fs/osd_ldiskfs.ko
mv $basemodpath/fs/ldiskfs.ko $basemodpath-osd-ldiskfs/fs/ldiskfs.ko
%endif
%if %{with zfs}
mkdir -p $basemodpath-osd-zfs/fs
mv $basemodpath/fs/osd_zfs.ko $basemodpath-osd-zfs/fs/osd_zfs.ko
%endif
%if %{with lustre_tests}
mkdir -p $basemodpath-tests/fs
mv $basemodpath/fs/llog_test.ko $basemodpath-tests/fs/llog_test.ko
mkdir -p $RPM_BUILD_ROOT%{_libdir}/lustre/tests/kernel/
mv $basemodpath/fs/kinode.ko $RPM_BUILD_ROOT%{_libdir}/lustre/tests/kernel/
%endif

:> lustre.files
:> lustre-devel.files

%if %{with servers} && %{with lustre_utils}
# The .ha_v2 extension identifies the heartbeat resource agent as using
# legacy syntax. Install a compatibility symlink to avoid conflicts when
# newer-style agents are added.
ln -s Lustre.ha_v2 $RPM_BUILD_ROOT%{_sysconfdir}/ha.d/resource.d/Lustre
echo '%{_sysconfdir}/ha.d/resource.d/Lustre.ha_v2' >>lustre.files
echo '%{_sysconfdir}/ha.d/resource.d/Lustre' >>lustre.files
echo '%dir %{_sysconfdir}/ha.d/' >>lustre.files
echo '%dir %{_sysconfdir}/ha.d/resource.d/' >>lustre.files
%endif

# systemd is on redhat, fedora, and suse
%if %{with systemd}
echo '%{_unitdir}/lnet.service' >>lustre.files
%endif

%if %{_vendor}=="redhat"
# The following scripts are Red Hat specific
%if %{with servers}
echo '%{_sysconfdir}/sysconfig/lustre' >>lustre.files
echo '%{_sysconfdir}/sysconfig/lsvcgss' >>lustre.files
echo '%{_sysconfdir}/init.d/lustre' >>lustre.files
%endif


echo '%dir %{_sysconfdir}/udev' >>lustre.files
echo '%dir %{_sysconfdir}/udev/rules.d' >>lustre.files
echo '%dir %{_sysconfdir}/udev/rules.d/99-lustre.rules' >>lustre.files

%if %{without systemd}
echo '%{_sysconfdir}/init.d/lnet' >>lustre.files
%endif

echo '%{_sysconfdir}/init.d/lsvcgss' >>lustre.files
%endif

%if %{with servers}
mkdir -p $RPM_BUILD_ROOT%{_prefix}/lib/ocf/resource.d/lustre/
install -m 0755 contrib/scripts/pacemaker/* $RPM_BUILD_ROOT%{_prefix}/lib/ocf/resource.d/lustre/
%endif

# fc18 needs 'x' permission for library files
find $RPM_BUILD_ROOT -name \*.so -type f -exec chmod +x {} \;

%if %{with lnet_dlc}
rm -f $RPM_BUILD_ROOT%{_libdir}/liblnetconfig.la
%if %{with static}
echo '%attr(-, root, root) %{_libdir}/liblnetconfig.a' >>lustre-devel.files
%endif
%if %{with shared}
echo '%attr(-, root, root) %{_libdir}/liblnetconfig.so' >>lustre.files
echo '%attr(-, root, root) %{_libdir}/liblnetconfig.so.*' >>lustre.files
%endif
%endif

%if %{with ldiskfs}
echo '%{_libdir}/libiam.a' >>lustre-devel.files
echo '%dir %{modules_fs_path}/%{lustre_name}-osd-ldiskfs/' >>lustre.files
echo '%dir %{modules_fs_path}/%{lustre_name}-osd-ldiskfs/fs/' >>lustre.files
%endif

if [ -d $RPM_BUILD_ROOT%{_libdir}/lustre/snmp ] ; then
	echo '%{_libdir}/lustre/snmp' >>lustre.files
fi

%if %{with lustre_utils}
mkdir -p $RPM_BUILD_ROOT/%{_datadir}/lustre
find $RPM_BUILD_ROOT%{_libdir}/lustre -name \*.la -type f -exec rm -f {} \;
%endif

%if %{with lustre_modules}
# mark modules executable for find-debuginfo.sh
find $RPM_BUILD_ROOT/lib/modules -name \*.ko -type f -exec chmod u+x {} \;
%endif


%if %{with lustre_tests}
:> lustre-tests.files
echo '%dir %{modules_fs_path}/%{lustre_name}-tests/' >>lustre-tests.files
echo '%dir %{modules_fs_path}/%{lustre_name}-tests/fs' >>lustre-tests.files
echo '%dir %{_libdir}/lustre/tests/' >>lustre-tests.files
echo '%{_libdir}/lustre/tests/*' >>lustre-tests.files
echo '%{_bindir}/mcreate' >>lustre-tests.files
echo '%{_bindir}/munlink' >>lustre-tests.files
echo '%{_sbindir}/wirecheck' >>lustre-tests.files
echo '%{_sbindir}/wiretest' >>lustre-tests.files
%endif


%files -f lustre.files
%defattr(-,root,root)
%{_sbindir}/*
%exclude %{_sbindir}/wirecheck
%exclude %{_sbindir}/wiretest
%if %{with zfs}
%exclude %{_sbindir}/zfsobj2fid
%endif
%if %{with lustre_utils}
%if %{with servers}
%dir %{_libexecdir}/lustre
%{_libexecdir}/lustre/lc_common
%{_libexecdir}/lustre/haconfig
%{_bindir}/lustre_req_history
%endif

%dir %{modules_fs_path}/%{lustre_name}
%dir %{modules_fs_path}
%{_bindir}/llobdstat
%{_bindir}/llstat
%{_bindir}/plot-llstat

%{_bindir}/lfs
%{_bindir}/lfs_migrate
/sbin/mount.lustre
%{_libdir}/liblustreapi.so
%if %{with manpages}
%{_mandir}/man?/*
%endif
%{_datadir}/lustre
%endif
%dir %{_libdir}/lustre/
%dir %{_sysconfdir}/udev/
%dir %{_sysconfdir}/udev/rules.d/
%{_sysconfdir}/udev/rules.d/99-lustre.rules
%config(noreplace) %{_sysconfdir}/ldev.conf
%if %{with lnet_dlc}
%config(noreplace) %{_sysconfdir}/lnet.conf
%endif
%config(noreplace) %{_sysconfdir}/modprobe.d/ko2iblnd.conf
%if %{with lustre_utils}
%config(noreplace) %{_sysconfdir}/lnet_routes.conf
%endif
%if %{with lustre_modules}

%if %{with ldiskfs}
%if %{with lustre_utils}
%files osd-ldiskfs-mount
%defattr(-,root,root)
%{_libdir}/lustre/mount_osd_ldiskfs.so
%endif
%endif

%if %{with zfs}
%if %{with lustre_utils}
%files osd-zfs-mount
%defattr(-,root,root)
%{_libdir}/lustre/mount_osd_zfs.so
%endif
%endif

%endif # with lustre_modules

%files devel -f lustre-devel.files
%defattr(-,root,root)
%{_includedir}/lustre
%{_libdir}/libptlctl.a
%{_libdir}/libcfsutil.a
%{_libdir}/liblustreapi.a

%if %{with servers}
%files resource-agents
%defattr(0755,root,root)
%dir %{_prefix}/lib/ocf/
%dir %{_prefix}/lib/ocf/resource.d/
%{_prefix}/lib/ocf/resource.d/lustre/
%endif

%if %{with lustre_tests}
%files tests -f lustre-tests.files
%defattr(-,root,root)
%endif

%if %{with lustre_iokit}
%files -n lustre-iokit
%defattr(-, root, root)
%{_bindir}/iokit-config
%{_bindir}/iokit-gather-stats
%{_bindir}/iokit-libecho
%{_bindir}/iokit-lstats
%{_bindir}/iokit-parse-ior
%{_bindir}/iokit-plot-obdfilter
%{_bindir}/iokit-plot-ost
%{_bindir}/iokit-plot-sgpdd
%{_bindir}/ior-survey
%{_bindir}/mds-survey
%{_bindir}/obdfilter-survey
%{_bindir}/ost-survey
%{_bindir}/sgpdd-survey
%doc lustre-iokit/ior-survey/README.ior-survey
%doc lustre-iokit/mds-survey/README.mds-survey
%doc lustre-iokit/obdfilter-survey/README.obdfilter-survey
%doc lustre-iokit/ost-survey/README.ost-survey
%doc lustre-iokit/sgpdd-survey/README.sgpdd-survey
%doc lustre-iokit/stats-collect/README.iokit-lstats
%endif

%post
%if %{with systemd}
%systemd_post lnet.service
%endif

%preun
%if %{with systemd}
%systemd_preun lnet.service
%endif

%postun
%if %{with systemd}
%systemd_postun_with_restart lnet.service
%endif

%clean
rm -rf $RPM_BUILD_ROOT
rm -rf %{_tmppath}/kmp
%changelog
* Tue Jul 30 2019 eich@suse.com
- Avoid
  0030-LU-12137-ldiskfs-properly-handle-VFS-parallel-lockin.patch
  0031-ldiskfs-local-iterate_dir
  on SLE <= 12.3
* Fri Jul 26 2019 nfbrown@suse.com
- 0031-ldiskfs-local-iterate_dir
  provide local iterate_dir() which doesn't invoke any
  security module.
* Mon Jul  8 2019 nfbrown@suse.com
- 0030-LU-12137-ldiskfs-properly-handle-VFS-parallel-lockin.patch
  Fix deadlock on server mount.
  In recent kernel, mounting a server-side filesystem will deadlock
  due to clumsy locking in the ldiskfs-scrub code.  This patch
  cleans that up
* Wed Jun 12 2019 aguerrero@suse.com
- 0029-Remove-libcfs-call-trace_arm64.patch
  Diff against libcfs/libcfs/linux/linux-debug.c in lustre-2.11.0
  where the problem with the unknown symbol in aarch64 is not present.
* Wed Mar  6 2019 nfbrown@suse.com
- 0027-Port-to-SLE15-SP1.patch
  Minor patch update to apply to SLE15-SP1
- 0028-ib_post_recv_const.patch
  Minor build fix
* Tue Oct 23 2018 nfbrown@suse.com
- Modify lustre-build-ldiskfs.m4 to detect
  SLE12-SP4 based on CONFIG_SUSE_VERSION
  rather than using kernel release numbers.
* Mon Oct 22 2018 nfbrown@suse.com
- Add support for SLE12-SP4.  Kernel is similar to
  SLE15 but has more patches than 15-GMC
  0026-Port-to-SLE12-SP4.patch
* Thu Oct 18 2018 nfbrown@suse.com
- Include more upstream patches needed for SLE15 kernel.
  0024-LU-11044-osd-ldiskfs-ext4_dir_operations-uses-iterat.patch
  0025-LU-11156-scrub-skip-project-quota-inode.patch
* Thu Oct 18 2018 nfbrown@suse.com
- Add missing export for ldiskfs_get_inode_loc
* Fri Sep 14 2018 nfbrown@suse.com
- update to Lustre 2.10.5
* Tue Aug 28 2018 nfbrown@suse.com
- Update to Lustre 2.10.4
* Wed Aug 22 2018 nfbrown@suse.com
- Port to SLE-15
* Thu Mar 22 2018 jeffm@suse.com
- Split out includes and build libraries into -devel package.
* Thu Mar  1 2018 jeffm@suse.com
- Update to Lustre 2.10.3
  * LU-10371 ptlrpc: check for posix_acl a_entries
  * LU-618 llite: IO accounting of page read
  * LU-10464 kernel: kernel update [SLES12 SP2 4.4.103-92.56]
  * LU-10458 kernel: kernel update [SLES12 SP3 4.4.103-6.38]
  * LU-10456 kernel: kernel update RHEL6.9 [2.6.32-696.18.7.el6]
  * LU-10455 kernel: kernel update RHEL7.4 [3.10.0-693.11.6.el7]
  * LU-10427 kernel: kernel update [SLES12 SP2 4.4.103-92.53]
  * LU-10425 kernel: kernel update [SLES12 SP3 4.4.103-6.33]
  * LU-10232 lov: call cl_object_attr_get under cl_attr lock
  * LU-10346 utils: use the correct lib path in mount_utils.c
  * LU-10267 llog: fix EOF handling in llog_client_next_block()
  * LU-10268 lfsck: postpone lfsck start until initialized
  * LU-10134 lfsck: not add requests if engine out of work
  * LU-5020 llite: don't reconnect MGC if connecting
  * LU-4134 obdclass: fix double free in failure path
  * LU-4134 obdclass: obd_device improvement
  * LU-10301 kernel: kernel update RHEL7.4 [3.10.0-693.11.1.el7]
  * LU-9558 llite: port lustre to unified handling of bdi
  * LU-7340 mdd: changelogs garbage collection
  * LU-9558 kernel: replace CURRENT_TIME macro
  * LU-7991 quota: project quota against ZFS backend
  * LU-7988 hsm: wake up cdt when requests are empty
  * LU-10256 hsm: enable setting archive_id in hsm_set
  * LU-6210 utils: Use C99 struct initializers in lfs_hsm_state()
  * LU-9611 lov: allow lov.*.stripe{size,count}=-1 param
  * LU-9997 ldlm: check lock cancellation in ldlm_cli_cancel()
  * LU-9894 lfsck: Print correct lfsck start info
  * LU-6210 utils: Use C99 initializer for lfsck_types_names
  * LU-9660 ptlrpc: do not wakeup every second
  * LU-10011 utils: suppress annoying messages for project quota
  * LU-10098 scripts: Fix mounted check in Lustre RA
  * LU-10220 mdd: fix buf alloc in mdd_changelog_data_store_by_fid
  * LU-8497 osp: handle remote -ENOMEM from osp_send_update_req()
  * LU-9941 lov: lsm_is_composite isn't right
  * LU-10086 libcfs: use dynamic minors for /dev/{lnet,obd}
  * LU-10241 kernel: kernel update RHEL6.9 [2.6.32-696.16.1.el6]
  * LU-10166 mdc: invalid free in changelog reader
  * LU-10040 nodemap: add nodemap idmap correctly
  * LU-10007 pacemaker: Use lctl and load lustre
  * LU-10015 o2iblnd: fix race at kiblnd_connect_peer
  * LU-9951 lustre_compat: add wrapper function for posix_acl_update_mode
  * LU-9578 llite: use security context if it's enabled in the kernel
  * LU-10141 llapi: integer overflow in llapi_changelog_start
  * LU-10150 build: Build with ZFS 0.7.3
  * LU-9840 lod: add ldo_dir_stripe_loaded
  * LU-10168 kernel: kernel update [SLES12 SP2 4.4.90-92.45]
  * LU-10132 llite: handle xattr cache refill race
  * LU-10164 kernel: kernel update [SLES12 SP3 4.4.92-6.18]
  * LU-10142 kernel: kernel update RHEL7.4 [3.10.0-693.5.2.el7]
  * LU-10131 llite: Update i_nlink on unlink
  * LU-10041 osd: osd-zfs to choose dnode size
  * LU-9782 osd-ldiskfs: avoid extra search
  * LU-7990 llite: increase whole-file readahead to RPC size
  * LU-4705 mdc: improve mdc_enqueue() error message
  * LU-9814 ldiskfs: restore simple_strtol in prealloc
  * LU-10029 osd-ldiskfs: make project inherit attr removeable
  * LU-9140 nrs: measure the runtime of dd directly
  * LU-7988 hsm: update many cookie status at once
  * LU-3719 ldiskfs: adjust s_mb_prealloc_table_size correctly
  * LU-9672 gss: fix expiration time of sunrpc cache
  * LU-9887 lfsck: calculate LFSCK speed properly
  * LU-9802 pfl: swapping lcm_entry_count correctly
  * LU-10023 kernel: kernel update [SLES12 SP3 4.4.82-6.9]
  * LU-9956 kernel: kernel upgrade [SLES12 SP3 4.4.82-6.3]
  * LU-10119 scripts: Correct shebang/hashpling format
  * LU-9416 hsm: add kkuc before sending registration RPCs
  * LU-9574 llite: pipeline readahead better with large I/O
  * LU-10000 kernel: kernel update [SLES12 SP2 4.4.74-92.38]
  * LU-7802 ldlm: No -EINVAL for canceled != unused
  * LU-8276 ldlm: Make lru clear always discard read lock pages
  * LU-8578 ldlm: ELC shouldn't wait on lock flush
  * LU-9469 ldiskfs: add additional attach_jinode call
  * LU-9929 nodemap: add default ACL unmapping handling
  * LU-10088 kernel: kernel update RHEL6.9 [2.6.32-696.13.2.el6]
  * LU-8541 ldlm: don't use jiffies as sysfs parameter
  * LU-9983 llog: skip non-exist log cancellation
  * LU-9930 llite: only clear lli_sai if the setter
  * LU-9682 nodemap: delete nids range from nodemap correctly
  * LU-9996 build: include MOFED lib
  * LU-9558 llite: user enhanced getattr functionality in newer kernels
  * LU-9870 build: handle SNMP missing on build box
  * LU-9733 obd: fix fsname parsing
  * LU-9417 mdc: excessive memory consumption by the xattr cache
- ldiskfs: revert SLES-specific unsupported features patch
- ldiskfs: use shim for clean_bdev_aliases
- autoconf: fix documentation for BI_RW and SUBMIT_BIO_2ARGS
- ldiskfs: ignore local quilt environment
- ldiskfs: test for SLES 12 SP2/SP3 via presence of clean_bdev_aliases
- ldiskfs: add support for SLES12-SP2 GA kernel
- ldiskfs: SLE12-SP3 GA support
- Added patches:
  * 0001-ldiskfs-revert-SLES-specific-unsupported-features-pa.patch
  * 0002-ldiskfs-use-shim-for-clean_bdev_aliases.patch
  * 0003-autoconf-fix-documentation-for-BI_RW-and-SUBMIT_BIO_.patch
  * 0004-ldiskfs-ignore-local-quilt-environment.patch
  * 0005-ldiskfs-test-for-SLES-12-SP2-SP3-via-presence-of-cle.patch
  * 0006-ldiskfs-add-support-for-SLES12-SP2-GA-kernel.patch
  * 0007-ldiskfs-SLE12-SP3-GA-support.patch
- Removed patches:
  * lu-7802-ldlm-no-einval-for-canceled-unused.patch
  * lu-8276-ldlm-make-lru-clear-always-discard-read-lock-pages.patch
  * lu-8578-ldlm-elc-shouldn-t-wait-on-lock-flush.patch
  * 0001-add-support-for-SLES12-SP2-GA-kernel.patch
  * 0002-use-bio_data_dir-instead-of-open-coding-it.patch
  * 0003-compat-for-block-layer.patch
  * 0004-clean-bdev.patch
  * 0005-initial-sles12-sp3.patch
* Mon Nov 20 2017 jeffm@suse.com
- Initial packaging.
- Lustre 2.10.1
- LU-7802 ldlm: No -EINVAL for canceled != unused
- LU-8276 ldlm: Make lru clear always discard read lock pages
- LU-8578 ldlm: ELC shouldn't wait on lock flush
- add support for SLES12-SP2 GA kernel
- use bio_data_dir instead of open coding it
- compat for block layer
- clean bdev
- initial sles12 sp3
- Added patches:
  * lu-7802-ldlm-no-einval-for-canceled-unused.patch
  * lu-8276-ldlm-make-lru-clear-always-discard-read-lock-pages.patch
  * lu-8578-ldlm-elc-shouldn-t-wait-on-lock-flush.patch
  * 0001-add-support-for-SLES12-SP2-GA-kernel.patch
  * 0002-use-bio_data_dir-instead-of-open-coding-it.patch
  * 0003-compat-for-block-layer.patch
  * 0004-clean-bdev.patch
  * 0005-initial-sles12-sp3.patch
